<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=oc_gsc
// ** ne pas modifier le fichier **

return [

	// A
	'aide_non_disponible' => 'Aquera part de l’ajuda en linha n’ei pas enqüèra disponibla tà aquesta lenga.',
	'avis_acces_interdit' => 'Accès proïbit.',
	'avis_article_modifie' => 'Atencion, @nom_auteur_modif@ qu’a trabalhat sus aqueth article hè @date_diff@ minutas',
	'avis_aucun_resultat' => 'Nat resultat.',
	'avis_chemin_invalide_1' => 'Lo camin qui avetz causit',
	'avis_chemin_invalide_2' => 'non sembla pas valid. Volhatz tornar a la pagina anteriora tà verificar las informacions hornidas.',
	'avis_connexion_echec_1' => 'La connexion au servider SQL que s’i ei mauescaduda.', # MODIF
	'avis_connexion_echec_2' => 'Tornatz a la pagina anteriora, e verificatz las informacions qui avetz hornidas.',
	'avis_connexion_echec_3' => '<b>N.B.</b> Sus hèra de serviders, que devetz <b>demandar</b> qu’activen lo vòste accès a la basa SQL abans de poder utilizar-la. Se ne’vs podetz pas connectar, verificatz qu’ajatz plan realizat aqueth procediment.', # MODIF
	'avis_connexion_ldap_echec_1' => 'La connexion au servider LDAP que s’i ei mauescaduda.',
	'avis_connexion_ldap_echec_2' => 'Tornatz a la pagina anteriora, e verificatz las informacions qui avetz hornidas. ',
	'avis_connexion_ldap_echec_3' => 'Alternativament, n’utilizetz pas lo supòrt LDAP tà importar utilizaires.', # MODIF
	'avis_deplacement_rubrique' => 'Atention! Aquera rubrica que contien @contient_breves@ brèvas@scb@: se la desplaçatz, que voleretz plan oscar aquera casa de confirmacion.',
	'avis_erreur_connexion_mysql' => 'Error de connexion SQL',
	'avis_espace_interdit' => '<b>Espaci proïbit</b><p>SPIP qu’ei ja installat.', # MODIF
	'avis_lecture_noms_bases_1' => 'Lo programa d’installacion n’a pas poscut legir los noms de las basas de dadas installadas.',
	'avis_lecture_noms_bases_2' => 'Sia nada basa n’ei pas disponibla, sia la foncion qui permet de listar las basas ei estada desactivada per rasons de seguretat (aquò qu’ei lo cas en çò de mei d’un aubergader).',
	'avis_lecture_noms_bases_3' => 'Dens la dusau alternativa, qu’ei probable qu’ua basa qui pòrta lo vòste nom de login e sia utilizabla:',
	'avis_non_acces_page' => 'Non podetz pas accedir a aquera pagina.',
	'avis_operation_echec' => 'L’operacion que s’i ei mauescaduda.',
	'avis_suppression_base' => 'ATENCION, suprimir las dadas qu’ei irreversible',

	// B
	'bouton_acces_ldap' => 'Ajustar l’accès a LDAP >>',
	'bouton_ajouter' => 'Ajustar',
	'bouton_demande_publication' => 'Demandar la publicacion d’aqueste article',
	'bouton_effacer_tout' => 'Esfaçar-ac tot',
	'bouton_envoyer_message' => 'Messatge definitiu: mandar',
	'bouton_modifier' => 'Modificar',
	'bouton_radio_afficher' => 'Afichar',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Afichar dens la tèra deus redactors connectats', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'Mandar los anoncis a l’adreiça:',
	'bouton_radio_envoi_liste_nouveautes' => 'Mandar la tèra de las nautats',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'N’aparéisher pas dens la tèra deus redactors', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'Non mandar pas nat anonci editoriau',
	'bouton_redirection' => 'TORNAR DIRIGIR',
	'bouton_relancer_installation' => 'Tornar lançar l’installacion',
	'bouton_suivant' => 'Seguent',
	'bouton_tenter_recuperation' => 'Ensajar de reparar',
	'bouton_test_proxy' => 'Ensajar lo proxy',
	'bouton_vider_cache' => 'Vueidar l’esconeder',

	// C
	'cache_modifiable_webmestre' => 'Lo webmèstre deu sit que pòt modificar aquestes paramètres.', # MODIF
	'calendrier_synchro' => 'S’utilizatz un logiciau d’agenda compatible <b>iCal</b> (Apple iCal, Mozilla Calendar, Ximian Evolution, KOrganizer...), que’u podetz sincronizar dab l’actualitat deu sit.',

	// D
	'date_mot_heures' => 'òras',

	// E
	'email' => 'e-mail',
	'email_2' => 'e-mail:',
	'entree_adresse_annuaire' => 'Adreiça de l’annuari',
	'entree_adresse_email' => 'La vòsta adreiça e-mail',
	'entree_base_donnee_1' => 'Adreiça de la basa de dadas',
	'entree_base_donnee_2' => '(Sovent, aquera adreiça que correspond a la deu vòste sit, a còps que correspond a la mençon "localhost", a còps, que’s dèisha vueida completament.)',
	'entree_biographie' => 'Biografia braca, en quauques mots.',
	'entree_chemin_acces' => '<b>Entrar</b> lo camin d’accès:',
	'entree_cle_pgp' => 'La vòsta clau PGP',
	'entree_contenu_rubrique' => '(Contengut de la rubrica en quauques mots.)',
	'entree_identifiants_connexion' => 'Los vòstes identificants de connexion...',
	'entree_informations_connexion_ldap' => 'Volhatz entrar dens aqueth formulari las informacions de connexion au vòste annuari LDAP.
L’administrator deu sistèma o de l’arret que’vs deu poder hornir
 aqueras informacions.', # MODIF
	'entree_infos_perso' => 'Qui ètz?',
	'entree_interieur_rubrique' => 'Laguens la rubrica:',
	'entree_liens_sites' => '<b>Ligam ipertèxt</b> (referéncia, sit de vesitar...)',
	'entree_login' => 'Lo vòste login',
	'entree_login_connexion_1' => 'Lo login de connexion',
	'entree_login_connexion_2' => '(Que correspond a còps au vòste login d’accès a l’FTP; a còps qu’es dèisha vueid)',
	'entree_mot_passe' => 'Lo vòste mot de santa Clara',
	'entree_mot_passe_1' => 'Mot de santa Clara tà la connexion',
	'entree_mot_passe_2' => '(Que correspond a còps au vòste mot de santa Clara tà l’FTP; a còps que’s dèisha vueid)',
	'entree_nom_fichier' => 'Volhatz entrar lo nom deu fichièr @texte_compresse@:',
	'entree_nom_pseudo' => 'Lo vòste nom o lo vòste pseudonim',
	'entree_nom_pseudo_1' => '(Lo vòste nom o lo vòste pseudonim)',
	'entree_nom_site' => 'Lo nom deu vòste sit',
	'entree_nouveau_passe' => 'Mot de santa Clara navèth',
	'entree_passe_ldap' => 'Mot de santa Clara',
	'entree_port_annuaire' => 'Lo numèro de pòrt de l’annuari',
	'entree_signature' => 'Signatura',
	'entree_titre_obligatoire' => '<b>Títol</b> [Obligatòri]<br />',
	'entree_url' => 'L’adreiça (URL) deu vòste sit',

	// I
	'ical_info1' => 'Aquera pagina que muisha metòdes diferents entà demorar en contacte dab la vita d’aqueth sit.',
	'ical_info2' => 'Tà tiéner mei informacions suber aqueras tecnicas, n’esitetz pas de consultar <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
	'ical_info_calendrier' => 'Que i a dus calendèrs a la vòsta disposicion. Lo permèr qu’ei un plan deu sit qui anóncia tots los articles publicats. Lo segond que contien los anoncis editoriaus en mei deus vòstes darrèrs messatges privats: que vs’ei reservat gràcias a ua clau personau, qui podetz modificar en tot moment en renovant lo vòste mot de santa Clara. ',
	'ical_methode_http' => 'Telecargament',
	'ical_methode_webcal' => 'Sincronizacion (webcal://)', # MODIF
	'ical_texte_prive' => 'Aqueth calendèr, d’us estrictament personau, que vs’informa de l’activitat editoriau privada d’aqueth sit (òbras e rendetz-vos personaus, articles e brèvas prepausats...).',
	'ical_texte_public' => 'Aqueth calendèr que’vs permet de seguir l’activitat publica d’aqueth sit (articles e brèvas publicats).',
	'ical_texte_rss' => 'Que podetz sindicar las nautats d’aqueste sit dens quin legider de fichièrs que sia en format XML/RSS (Rich Site Summary). Qu’ei tanben lo format qui permet a SPIP de legir las nautats publicadas dens autes sits en utilizar un format d’escambi compatible (sits sindicats). ',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Lista de corrièr',
	'ical_titre_rss' => 'Fichièrs «backend»',
	'icone_activer_cookie' => 'Activar lo cookie de correspondéncia',
	'icone_afficher_auteurs' => 'Afichar los autors',
	'icone_afficher_visiteurs' => 'Afichar los vesitaires',
	'icone_arret_discussion' => 'Quitar aquera discussion',
	'icone_calendrier' => 'Calendèr',
	'icone_creer_auteur' => 'Crear un autor nau e associà’u a aqueth article',
	'icone_creer_mot_cle' => 'Crear un mot clau nau e ligà’u a aqueth article',
	'icone_creer_rubrique_2' => 'Crear ua rubrica nava',
	'icone_modifier_article' => 'Modificar aqueth article',
	'icone_modifier_rubrique' => 'Modificar aquera rubrica',
	'icone_retour' => 'Tornar',
	'icone_retour_article' => 'Tornar a l’article',
	'icone_supprimer_cookie' => 'Suprimir lo cookie de correspondéncia',
	'icone_supprimer_rubrique' => 'Suprimir aquera rubrica',
	'icone_supprimer_signature' => 'Suprimir aquera signatura',
	'icone_valider_signature' => 'Validar aquera signatura',
	'image_administrer_rubrique' => 'Que podetz administrar aquera rubrica',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => '1 article',
	'info_activer_cookie' => 'Que podetz activar un <b>cookie de correspondéncia</b>; aquò que’vs permeterà de passar aisit deu sit public au sit privat.',
	'info_administrateur' => 'Administrator', # MODIF
	'info_administrateur_1' => 'Administrator', # MODIF
	'info_administrateur_2' => 'deu sit(<i>d’utilizar dab precaucion</i>)',
	'info_administrateur_site_01' => 'S’ètz administrator/tritz deu sit, volhatz', # MODIF
	'info_administrateur_site_02' => 'clicar aqueth ligam',
	'info_administrateurs' => 'Administrators', # MODIF
	'info_administrer_rubrique' => 'Que podetz administrar aquera rubrica',
	'info_adresse' => 'a l’adreiça:',
	'info_adresse_url' => 'Adreiça (URL) deu sit public',
	'info_aide_en_ligne' => 'Ajuda en linha SPIP',
	'info_ajout_image' => 'Quan ajustatz imatges com estacaments juntats a un article, SPIP que pòt crear automaticament entà vos vinhetas (miniaturas) deus imatges inserits. Aquò que permet per exemple de crear automaticament ua galaria o un pòrtfòlio.',
	'info_ajouter_rubrique' => 'Ajustar ua auta rubrica d’administrar:',
	'info_annonce_nouveautes' => 'Anonci de las nautats',
	'info_article' => 'article',
	'info_article_2' => 'articles',
	'info_article_a_paraitre' => 'Los articles pòstdatats per paréisher',
	'info_articles_02' => 'articles',
	'info_articles_2' => 'Articles',
	'info_articles_auteur' => 'Los articles d’aqueth autor',
	'info_articles_trouves' => 'Articles trobats',
	'info_attente_validation' => 'Los vòstes articles en espèra de validacion',
	'info_aujourdhui' => 'uei:',
	'info_auteurs' => 'Los autors',
	'info_auteurs_par_tri' => 'autors@partri@',
	'info_auteurs_trouves' => 'Autors trobats',
	'info_authentification_externe' => 'Autentificacion extèrna',
	'info_avertissement' => 'Avís',
	'info_base_installee' => 'L’estructura de la vòsta basa de dadas qu’ei installada.',
	'info_chapeau' => 'Capèth',
	'info_chapeau_2' => 'Capèth:',
	'info_chemin_acces_1' => 'Opcions: <b>camin d’accès dens l’annuari</b>',
	'info_chemin_acces_2' => 'Ara que devetz configurar lo camin d’accès a las informacions dens l’annuari.', # MODIF
	'info_chemin_acces_annuaire' => 'Opcions:<b>camin d’accès dens l’annuari',
	'info_choix_base' => 'Tresau estapa:',
	'info_classement_1' => '<sup>èr</sup> de @liste@',
	'info_classement_2' => '<sup>au</sup> de @liste@',
	'info_code_acces' => 'N’oblidetz pas los vòstes còdes d’accès pròpis!',
	'info_config_suivi' => 'S’aquera adreiça correspond a ua lista de corrièr, que podetz indicar ça devath l’adreiça on los participants au sit e pòden inscrive’s. Aquera adreiça que pòt estar ua URL (per exemple la pagina d’inscripcion a la lista peu web), o ua adreiça e-mail tienent un subjècte especific (per exemple: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Que podetz arrecéber automaticament, per e-mail, los anoncis pertocant l’activitat editoriau d’aqueth sit. Tà aquò har, que’vs podetz abonar a la lista de corrièr seguenta:',
	'info_confirmer_passe' => 'Confirmar aqueth mot de santa Clara navèth:',
	'info_connexion_base' => 'Dusau estapa: <b>Ensai de connexion a la basa</b>',
	'info_connexion_ldap_ok' => 'La connexion LDAP que s’i ei escaduda.</b><p> Que podetz passar a l’estapa seguenta.', # MODIF
	'info_connexion_mysql' => 'Permèra estapa:<b>La vòsta connexion SQL</b>',
	'info_connexion_ok' => 'La connexion que s’i ei escaduda.',
	'info_contact' => 'Contacte',
	'info_contenu_articles' => 'Contengut deus articles',
	'info_creation_paragraphe' => '(Entà crear paragrafs, que sufís que deishetz linhas vueidas.)', # MODIF
	'info_creation_rubrique' => 'Abans de poder escríver articles,<br /> que devetz crear aumensh ua rubrica.<br />',
	'info_creation_tables' => 'Quatau estapa: <b>Creacion de las taulas de la basa</b>',
	'info_creer_base' => '<b>Crear</b> ua basa de dadas navèra:',
	'info_dans_rubrique' => 'Dens la rubrica:',
	'info_date_publication_anterieure' => 'Data anteriora de publicacion:',
	'info_date_referencement' => 'DATA DE REFERÉNCIAMENT D’AQUETH SIT:',
	'info_derniere_etape' => 'Darrèra estapa: <b>Qu’ei acabat!',
	'info_descriptif' => 'Descriptiu:',
	'info_discussion_cours' => 'Discussions en cors',
	'info_ecrire_article' => 'Abans de poder escríver articles, que’vs cau crear aumensh ua rubrica.',
	'info_email_envoi' => 'Adreiça e-mail de mandadís (opcionau)',
	'info_email_envoi_txt' => 'Indicatz ací l’adreiça d’utilizar tà enviar los e-mails (a fauta d’aquò, que s’utilizarà l’adreiça destinatari com adreiça de mandadís):',
	'info_email_webmestre' => 'Adreiça e-mail deu responsable deu sit (opcionau)', # MODIF
	'info_envoi_email_automatique' => 'Mandadís d’e-mails automatics',
	'info_envoyer_maintenant' => 'Mandar ara',
	'info_etape_suivante' => 'Passar a l’estapa seguenta',
	'info_etape_suivante_1' => 'Que podetz passar a l’estapa seguenta.',
	'info_etape_suivante_2' => 'Que podetz passar a l’estapa seguenta.',
	'info_exportation_base' => 'exportacion de la basa de cap tà @archive@',
	'info_facilite_suivi_activite' => 'Tà facilitar lo seguit de l’activitat editoriau deu sit, SPIP que’vs pòt hornir per e-mail, per exemple a ua lista de corrièr deus redactors, l’anonci de las demandas de publicacion e de las validacions d’articles.', # MODIF
	'info_fichiers_authent' => 'Fichièrs d’autentificacion « .htpasswd »',
	'info_forums_abo_invites' => 'Lo vòste sit web que horneish  forums entaus abonats; dens lo sit public los vesitaires que son convidats a registrà’s.', # MODIF
	'info_gauche_admin_tech' => '<b>A aquera pagina, sonque los responsables deu sit qu’i pòden accedir.</b><p> Que permet de trobar las diferentas foncions de mantienença tecnica. Daubuas qu’implican un procès d’autentificacion especific que necessita un accès FTP au sit web.', # MODIF
	'info_gauche_auteurs' => 'Que trobaratz ací tots los autors deu sit. La color de las icònas que n’indica l’estatut (administrator = verd; redactor = jaune).', # MODIF
	'info_gauche_auteurs_exterieurs' => 'Los autors exteriors, shens accès au sit, que son indicats per ua icòna blava; los autors esfaçats per ua caisha de las dèishas.', # MODIF
	'info_gauche_messagerie' => 'La messatjaria que’vs permet d’escambiar messatges entre redactors, de servar mementos (tau vòste usatge personau) o d’afichar anoncis sus la pagina d’arcuelh de l’espaci privat (s’ètz administrator/tritz).', # MODIF
	'info_gauche_statistiques_referers' => 'Aquera pagina que presenta la lista deus <i>referiders</i>, qu’ei a díser deus sits qui contienen ligams miant de cap tau vòste quite sit, mes unicament ièr e uei: aquera lista que s’actualiza cada 24 òras.',
	'info_gauche_visiteurs_enregistres' => 'Que trobaratz aquí los vesitaires registrats
 dens l’espaci public deu sit (forums dab abonament).',
	'info_generation_miniatures_images' => 'Congreacion de miniaturas deus imatges',
	'info_hebergeur_desactiver_envoi_email' => 'Daubuns aubergaders que desactivan lo mandadís automatic
 d’e-mails dempuish los lors serviders. En aqueth cas, las foncionalitats seguentas
 d’SPIP non foncionaràn pas.',
	'info_hier' => 'gèr:',
	'info_identification_publique' => 'La vòsta identitat publica...',
	'info_image_process' => 'Volhatz seleccionar lo melhor metòde de fabricacion de las vinhetas en clicar sus l’imatge correspondent.',
	'info_image_process2' => '<b>N.B.</b> <i>Se nat imatge n’apareish pas, alavetz lo servider qu’aubèrga lo vòste sit non l’an pas configurat entà utilizar aisinas taus. Se desiratz d’utilizar aqueras foncions, contactatz lo responsable tecnic e demandatz las extensions «GD» o «Imagick».</i>', # MODIF
	'info_images_auto' => 'Imatges calculats automaticament',
	'info_informations_personnelles' => 'Cincau estapa: <b>Informacions personaus</b>',
	'info_inscription_automatique' => 'Inscripcion automatica de redactors navèths', # MODIF
	'info_jeu_caractere' => 'Jòc de caractèrs deu sit',
	'info_jours' => 'dias',
	'info_laisser_champs_vides' => 'deishar aqueths camps vueids)',
	'info_langues' => 'Lengas deu sit',
	'info_ldap_ok' => 'L’autentificacion LDAP qu’ei installada.',
	'info_lien_hypertexte' => 'Ligam ipertèxt:',
	'info_liste_redacteurs_connectes' => 'Tèra deus redactors connectats', # MODIF
	'info_login_existant' => 'Aqueth login ja qu’existeish.',
	'info_login_trop_court' => 'Login tròp cort.',
	'info_maximum' => 'maximum:',
	'info_meme_rubrique' => 'Dens la medisha rubrica',
	'info_message_en_redaction' => 'Los vòstes messatges en cors de redaccion',
	'info_message_technique' => 'Messatge tecnic:',
	'info_messagerie_interne' => 'Messatjaria intèrna',
	'info_mise_a_niveau_base' => 'Hicada a nivèu de la vòsta basa SQL',
	'info_mise_a_niveau_base_2' => '{{Atencion!}} Qu’avetz installada ua version
  deus fichièrs SPIP {anteriora} a la qui i avèva
  abans sus aqueste sit: que riscatz de pèrder la vòsta basa de dadas
   e lo vòste sit non foncionarà plus.<br />{{Tornatz installar los
  fichièrs d’SPIP.}}',
	'info_modifier_rubrique' => 'Modificar la rubrica:',
	'info_modifier_titre' => 'Modificar: @titre@',
	'info_mon_site_spip' => 'Lo men sit SPIP',
	'info_moyenne' => 'mejana:',
	'info_multi_cet_article' => 'Lenga d’aqueste article:',
	'info_multi_langues_choisies' => 'Volhatz seleccionar ça devath las lengas qui son a posita deus redactors deu vòste sit.
  Las lengas ja emplegadas dens lo vòste sit (afichadas en permèras) ne’s pòden pas desactivar.', # MODIF
	'info_multi_secteurs' => '... sonque tà las rubricas a l’arradit deu sit?',
	'info_nom' => 'Nom',
	'info_nom_destinataire' => 'Nom deu destinatari',
	'info_nom_site' => 'Nom deu vòste sit',
	'info_nombre_articles' => '@nb_articles@ articles,',
	'info_nombre_rubriques' => '@nb_rubriques@ rubricas,',
	'info_nombre_sites' => '@nb_sites@ sits,',
	'info_non_deplacer' => 'De non desplaçar pas...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP que pòt mandar, regularament, l’anonci de las darrèras nautats deu sit
 (articles e brèvas publicats recentament).',
	'info_non_envoi_liste_nouveautes' => 'Non mandar pas la tèra de las nautats',
	'info_non_modifiable' => 'ne’s pòt pas modificar',
	'info_non_suppression_mot_cle' => 'Non vòi pas suprimir aqueth mot clau.',
	'info_notes' => 'Nòtas',
	'info_nouvel_article' => 'Article nau',
	'info_nouvelle_traduction' => 'Arrevirada nava:',
	'info_numero_article' => 'ARTICLE NUMÈRO:',
	'info_obligatoire_02' => '[Obligatòri]', # MODIF
	'info_option_accepter_visiteurs' => 'Acceptar l’inscripcion deus vesitaires deu sit public', # MODIF
	'info_option_ne_pas_accepter_visiteurs' => 'Arrefusar l’inscripcion de vesitaires', # MODIF
	'info_options_avancees' => 'OPCIONS AVANÇADAS',
	'info_ou' => 'o... ',
	'info_page_interdite' => 'Pagina proïbida',
	'info_par_nombre_article' => '(per nombre d’articles)',
	'info_passe_trop_court' => 'Mot de santa Clara tròp cort.',
	'info_passes_identiques' => 'Los dus mots de santa Clara non son pas identics.',
	'info_plus_cinq_car' => 'mei de 5 caractèrs',
	'info_plus_cinq_car_2' => '(mei de 5 caractèrs)',
	'info_plus_trois_car' => '(mei de 3 caractèrs)',
	'info_popularite' => 'popularitat: @popularite@; vesitas: @visites@',
	'info_post_scriptum' => 'Post-scriptum',
	'info_post_scriptum_2' => 'Post-scriptum:',
	'info_pour' => 'entà',
	'info_preview_texte' => 'Qu’ei possible de previsualizar lo sit com s’avèvan publicat tots los articles e brèvas (qui tienen aumensh l’estatut "prepausat"). E la cau obrir, aquera possibilitat, aus administrators sonque, a tots los redactors, o non pas a degun?', # MODIF
	'info_procedez_par_etape' => 'proceditz estapa per estapa',
	'info_procedure_maj_version' => 'Que cau lançar la procedura d’actualizacion tà adaptar
 la basa de dadas a la version navèra d’SPIP.',
	'info_ps' => 'P.S.',
	'info_publier' => 'publicar',
	'info_publies' => 'Los vòstes articles publicats en linha',
	'info_question_accepter_visiteurs' => 'S’a las esqueletas deu vòste sit web e’s preved lo registrament de vesitaires shens accès a l’espaci privat, volhatz activar l’opcion seguenta:', # MODIF
	'info_question_inscription_nouveaux_redacteurs' => 'Acceptatz que redactors navèths e s’inscrívian
 a partir deu sit public? S’ac acceptatz, los vesitaires que’s poiràn inscríver
 mercés a un formulari automatizat e alavetz qu’accediràn a l’espaci privat entà
 perpausar articles.<blockquote><i> Durant la fasa d’inscripcion, los utilizaires que receben un e-mail automatic
 qui’us balha un còde d’accès au sit privat.
Daubuns aubergaders n’autorizan pas lo mandadís d’e-mails dempuish los lors serviders: en aqueth cas, l’inscripcion automatica qu’ei
 impossibla.', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
	'info_racine_site' => 'Arradit deu sit',
	'info_recharger_page' => 'Volhatz tornar cargar aquera pagina dens un momenton.',
	'info_recherche_auteur_zero' => '<b>Nat resultat trobat entà "@cherche_auteur@".',
	'info_recommencer' => 'Volhatz tornar començar.',
	'info_redacteur_1' => 'Redactor',
	'info_redacteur_2' => 'qui accedeish a l’espaci privat (<i>recomandat</i>)',
	'info_redacteurs' => 'Redactors',
	'info_redaction_en_cours' => 'EN CORS DE REDACCION',
	'info_redirection' => 'Redireccion',
	'info_refuses' => 'Los vòstes articles arrefusats',
	'info_reglage_ldap' => 'Opcions: <b>Reglatge de l’importacion LDAP</b>',
	'info_renvoi_article' => '<b>Redireccion.</b> Aqueth article que renvia a la pagina:',
	'info_reserve_admin' => 'Sonque los administrators que pòden modificar aquera adreiça.', # MODIF
	'info_restreindre_rubrique' => 'Restrénher la gestion a la rubrica:',
	'info_resultat_recherche' => 'Resultats de la cèrca:',
	'info_rubriques' => 'Rubricas',
	'info_rubriques_02' => 'rubricas',
	'info_rubriques_trouvees' => 'Rubricas trobadas',
	'info_sans_titre' => 'Shens títol',
	'info_selection_chemin_acces' => '<b>Seleccionatz</b> ça devath lo camin d’accès dens l’annuari:',
	'info_signatures' => 'signaturas',
	'info_site' => 'Sit',
	'info_site_2' => 'sit: ',
	'info_site_min' => 'sit',
	'info_site_reference_2' => 'Sit referenciat',
	'info_site_web' => 'SIT WEB:', # MODIF
	'info_sites' => 'sits',
	'info_sites_lies_mot' => 'Los sits referenciats ligats a aqueth mot clau',
	'info_sites_proxy' => 'Utilizar un proxy',
	'info_sites_trouves' => 'Sits trobats',
	'info_sous_titre' => 'Sostítol:',
	'info_statut_administrateur' => 'Administrator', # MODIF
	'info_statut_auteur' => 'Estatut d’aqueth autor:', # MODIF
	'info_statut_redacteur' => 'Redactor',
	'info_statut_utilisateurs_1' => 'Estatut predefinit deus utilizaires importats', # MODIF
	'info_statut_utilisateurs_2' => 'Causitz l’estatut d’atribuir a las personas presentas dens l’annuari LDAP quan e’s connèctan lo permèr còp. Que poiratz puish modificar aqueth estatut entà cada autor un cas per un.', # MODIF
	'info_suivi_activite' => 'Seguit de l’activitat editoriau',
	'info_surtitre' => 'Subertítol:',
	'info_taille_maximale_vignette' => 'Talha maximau de las vinhetas congreadas peu sistèma:',
	'info_terminer_installation' => 'Ara que podetz acabar la procedura d’installacion estandard.',
	'info_texte' => 'Tèxt',
	'info_texte_explicatif' => 'Tèxt explicatiu',
	'info_texte_long' => '(lo tèxt qu’ei long: qu’apareish doncas en tròç distints qui’s tornaràn colar un còp validats.)',
	'info_texte_message' => 'Tèxt deu vòste messatge:', # MODIF
	'info_texte_message_02' => 'Tèxt deu messatge',
	'info_titre' => 'Títol:',
	'info_total' => 'totau: ',
	'info_tous_articles_en_redaction' => 'Tots los articles en cors de redaccion',
	'info_tous_articles_presents' => 'Tots los articles publicats dens aquera rubrica',
	'info_tous_les' => 'tots los:',
	'info_tout_site' => 'Tot lo sit ',
	'info_tout_site2' => 'N’an pas arrevirat l’article cap tà aquera lenga.',
	'info_tout_site3' => 'Qu’an arrevirat l’article cap tà  aquera lenga, mes qu’an portat puish modificacions a l’article de referéncia. Que cau actualizar l’arrevirada.',
	'info_tout_site4' => 'Qu’an arrevirat l’article cap tà aquera lenga, e l’arrevirada qu’ei actualizada.',
	'info_tout_site5' => 'Article originau.',
	'info_tout_site6' => '<b>Atencion:</b> sonque los articles originaus que s’afichan.
Las arreviradas que s’assòcian a l’originau,
ua color qu’indica lo lor estat:',
	'info_travail_colaboratif' => 'Trabalh collaboratiu suus articles',
	'info_un_article' => 'un article, ',
	'info_un_site' => 'un sit, ',
	'info_une_rubrique' => 'ua rubrica, ',
	'info_une_rubrique_02' => '1 rubrica',
	'info_url' => 'URL:',
	'info_urlref' => 'Ligam ipertèxt:',
	'info_utilisation_spip' => 'Ara que podetz començar d’utilizar lo sistèma de publicacion assistida...',
	'info_visites_par_mois' => 'Afichatge per mes:',
	'info_visiteur_1' => 'Vesitaire',
	'info_visiteur_2' => 'deu sit public',
	'info_visiteurs' => 'Vesitaires',
	'info_visiteurs_02' => 'Vesitaires deu sit public',
	'install_echec_annonce' => 'L’installacion que s’i mauescairà, o qu’abotirà a un sit non foncionau...',
	'install_extension_mbstring' => 'SPIP non fonciona pas dab:',
	'install_extension_php_obligatoire' => 'SPIP qu’exigeish l’extension php:',
	'install_select_langue' => 'Seleccionatz ua lenga puish clicatz lo boton «seguent» entà aviar la procedura d’installacion.',
	'intem_redacteur' => 'redactor',
	'item_accepter_inscriptions' => 'Acceptar las inscripcions',
	'item_activer_messages_avertissement' => 'Activar los messatges d’avertiment',
	'item_administrateur_2' => 'administrator', # MODIF
	'item_afficher_calendrier' => 'Afichar dens lo calendèr',
	'item_choix_administrateurs' => 'los administrators', # MODIF
	'item_choix_generation_miniature' => 'Congrear automaticament las miniaturas deus imatges.',
	'item_choix_non_generation_miniature' => 'Non congrear pas nada miniatura deus imatges.',
	'item_choix_redacteurs' => 'los redactors',
	'item_choix_visiteurs' => 'los vesitaires deu sit public',
	'item_creer_fichiers_authent' => 'Crear fichièrs .htpasswd',
	'item_login' => 'Login',
	'item_mots_cles_association_articles' => 'aus articles',
	'item_mots_cles_association_rubriques' => 'a las rubricas',
	'item_mots_cles_association_sites' => 'aus sits referenciats o sindicats',
	'item_non' => 'Non',
	'item_non_accepter_inscriptions' => 'N’acceptar pas las inscripcions',
	'item_non_activer_messages_avertissement' => 'Nat messatge d’avertiment',
	'item_non_afficher_calendrier' => 'De non pas afichar dens lo calendèr',
	'item_non_creer_fichiers_authent' => 'Non crear pas aqueths fichièrs',
	'item_non_publier_articles' => 'Non publicar pas los articles abans la data de publicacion prevista.',
	'item_nouvel_auteur' => 'Autor nau',
	'item_nouvelle_rubrique' => 'Rubrica nava',
	'item_oui' => 'Òc',
	'item_publier_articles' => 'Publicar los articles, quina que sia la soa data de publicacion',
	'item_reponse_article' => 'Responsa a l’article',
	'item_visiteur' => 'vesitaire',

	// J
	'jour_non_connu_nc' => 'n.c.',

	// L
	'lien_ajouter_auteur' => 'Ajustar aqueth autor',
	'lien_email' => 'e-mail',
	'lien_nom_site' => 'NOM DEU SIT:',
	'lien_retirer_auteur' => 'Tirar l’autor',
	'lien_site' => 'sit',
	'lien_tout_deplier' => 'Desplegar tot',
	'lien_tout_replier' => 'Tornar plegar',
	'lien_trier_nom' => 'Triar per nom',
	'lien_trier_nombre_articles' => 'Triar per nombre d’articles',
	'lien_trier_statut' => 'Triar per estatut',
	'lien_voir_en_ligne' => 'VÉDER EN LINHA:',
	'logo_article' => 'LÒGO DE L’ARTICLE', # MODIF
	'logo_auteur' => 'LÒGO DE L’AUTOR', # MODIF
	'logo_rubrique' => 'LÒGO DE LA RUBRICA', # MODIF
	'logo_site' => 'LÒGO D’AQUETH SIT', # MODIF
	'logo_standard_rubrique' => 'LÒGO ESTANDARD DE LAS RUBRICAS', # MODIF
	'logo_survol' => 'LÒGO TAU SUBERVÒL', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'Causida de la vòsta basa',
	'module_fichier_langue' => 'Fichièr de lenga',
	'module_raccourci' => 'Acorcida',
	'module_texte_affiche' => 'Tèxt afichat',
	'module_texte_explicatif' => 'Que podetz inserir las acorcidas seguentas dens las esqueletas deu vòste sit public. Que s’arreviraràn automaticament dens las diferentas lengas tà las quaus existeish un fichièr de lenga.',
	'module_texte_traduction' => 'Lo fichièr de lenga «@module@» qu’ei disponible en:',
	'mois_non_connu' => 'non conegut',

	// O
	'onglet_repartition_actuelle' => 'uei lo dia',

	// R
	'required' => '[Obligatòri]', # MODIF

	// S
	'statut_admin_restreint' => '(admin. restrent)', # MODIF

	// T
	'taille_cache_image' => 'Los imatges qu’SPIP a calculat automaticament (vinhetas deus documents, títols presentats en forma grafica, foncions matematicas en format TeX...) qu’ocupan dens lo repertòri @dir@ un totau de @taille@.',
	'taille_cache_octets' => 'Ara la talha de l’esconeder que compassa @octets@.', # MODIF
	'taille_cache_vide' => 'L’esconeder qu’ei vueid.',
	'taille_repertoire_cache' => 'Talha deu repertòri esconeder',
	'text_article_propose_publication' => 'Article perpausat entà la publicacion. N’esitetz pas de dar la vòsta idèa gràcias au forum estacat a aqueth article (en baish de pagina).', # MODIF
	'texte_acces_ldap_anonyme_1' => 'Daubuns serviders LDAP n’accèptan pas nat accès anonim. En aqueth cas, que cau especificar un identificant d’accès iniciau tà poder puish cercar informacions dens l’annuari. Totun, los camps seguents que’s poiràn deishar vueids dens la màger part deus cas.',
	'texte_admin_effacer_01' => 'Aquera comanda qu’esfaça <i>tot</i> lo contengut de la basa de dadas,
 inclús <i>tots</i> los accès redactors e administrators. Un còp que l’auratz executada, qu’auratz de tornar lançar l’installacion d’SPIP tà tornar crear ua basa navèra atau com un permèr accès administrator.', # MODIF
	'texte_adresse_annuaire_1' => '(Se lo vòste annuari ei installat sus la medisha maquina qu’aqueth sit web, que s’ageish probable de "localhost".)',
	'texte_ajout_auteur' => 'L’autor seguent qu’ei estat ajustat a l’article:',
	'texte_annuaire_ldap_1' => 'S’acceditz a un annuari (LDAP), que’u podetz utilizar tà importar automaticament utilizaires devath SPIP.', # MODIF
	'texte_article_statut' => 'Aqueth article qu’ei:',
	'texte_article_virtuel' => 'Article virtuau',
	'texte_article_virtuel_reference' => '<b>Article virtuau:</b> article referenciat dens lo vòste sit SPIP, mes redirigit de cap tà ua auta URL. Tà suprimir la redireccion, esfaçatz l’URL ça suber.',
	'texte_aucun_resultat_auteur' => 'Nat resultat entà "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Aqueste sit que pòt indicà’vs de contunh la tèra deus redactors connectats, çò qui’vs permet d’escambiar messatges en dirècte. Que podetz decidir de n’aparéisher pas dens aquera tèra (qu’ètz "invisible/a" taus autes utilizaires).', # MODIF
	'texte_auteurs' => 'LOS AUTORS',
	'texte_choix_base_1' => 'Causitz la vòsta basa:',
	'texte_choix_base_2' => 'Lo servider SQL que contien mei d’ua basa de dadas.',
	'texte_choix_base_3' => '<b>Causitz</b> ça devath la qui lo vòste aubergader e vs’a atribuida:',
	'texte_compte_element' => '@count@ element',
	'texte_compte_elements' => '@count@ elements',
	'texte_connexion_mysql' => 'Consultatz las informacions que lo vòste aubergader e forneish: qu’i devetz trobar, se lo vòste aubergader supòrta SQL, los còdes de connexion au servider SQL.', # MODIF
	'texte_contenu_article' => '(Contengut de l’article en quauques mots.)',
	'texte_contenu_articles' => 'Segon la maqueta que lo vòste sit a adoptada, que podetz decidir
 que daubuns elements deus articles non s’utilizen pas.
 Utilizatz la tèra ça devath entà indicar quins elements son disponibles.',
	'texte_crash_base' => 'Se la vòsta basa de dadas s’i ei
 mauescaduda, que podetz ensajar ua reparacion
 automatica.',
	'texte_creer_rubrique' => 'Abans de poder escríver articles,<br /> que devetz crear ua rubrica.',
	'texte_date_creation_article' => 'DATA DE CREACION DE L’ARTICLE:',
	'texte_date_publication_anterieure' => 'DATA DE PUBLICACION ANTERIORA :',
	'texte_date_publication_anterieure_nonaffichee' => 'N’afichar pas nada data de publicacion anteriora.',
	'texte_date_publication_article' => 'DATA DE PUBLICACION EN LINHA :',
	'texte_descriptif_rapide' => 'Descriptiu rapid',
	'texte_effacer_base' => 'Esfaçar la basa de dadas SPIP',
	'texte_en_cours_validation' => 'Que’s perpausa de publicar los articles e brèvas ça devath. N’esitetz pas de dar la vòsta idèa gràcias aus forums qui i son estacats.', # MODIF
	'texte_enrichir_mise_a_jour' => 'Que podetz enriquir la compaginacion deu vòste tèxt en utilizar "acorcidas tipograficas".',
	'texte_fichier_authent' => '<b>E deu crear, SPIP, fichièrs especiaus  <tt>.htpasswd</tt>
  e <tt>.htpasswd-admin</tt> dens lo repertòri @dossier@?</b><p>
  Aqueths fichièrs que’vs pòden servir tà restrénher l’accès aus autors
  e administrators alhors dens lo vòste sit
  (programa extèrne d’estadisticas, per exemple).<p>
 Se ne’vs serveish pas, que podetz deishar aquesta opcion
  a la soa valor predefinida (nada creacion
  deus fichièrs).', # MODIF
	'texte_informations_personnelles_1' => 'Ara lo sistèma que’vs crearà un accès personalizat au sit.',
	'texte_informations_personnelles_2' => '(Nòta: se s’ageish d’ua reïnstallacion, e se lo vòste accès fonciona enqüèra, que podetz', # MODIF
	'texte_introductif_article' => '(Tèxt introductiu de l’article.)',
	'texte_jeu_caractere' => 'Aquesta opcion qu’ei utila se lo vòste sit deu afichar alfabets
 diferents de l’alfabet latin (o "occidentau") e los sons derivats.
 En aqueth cas, que cau cambiar lo reglatge predefinit entà utilizar
 un jòc de caractèrs apropiat. N’oblidetz pas tanpòc d’adaptar
 lo sit public en consequéncia (balisa <tt>#CHARSET</tt>).',
	'texte_login_ldap_1' => '(Deishar vueid entà un accès anonim, o picar lo camin complet, per exemple «<tt>uid=fabre, ou=usanciers, dc=mon-domeni, dc=com</tt>».)',
	'texte_login_precaution' => 'Atencion! Aquò qu’ei lo login dab lo quau ètz ara connectat/ada. 
 Utilizatz aqueste formulari dab precaucion...',
	'texte_mise_a_niveau_base_1' => 'Que vienetz d’actualizar los fichièrs SPIP.
 Ara que cau hicar a nivèu la basa de dadas
 deu sit.',
	'texte_modifier_article' => 'Modificar l’article:',
	'texte_multilinguisme' => 'Se desiratz de gerir articles en mei d’una lenga, dab ua navigacion complèxa, que podetz hornir un menut entà causir la lenga deus articles e/o de las rubricas, en foncion de l’organizacion deu vòste sit.', # MODIF
	'texte_multilinguisme_trad' => 'Que podetz tanben activar un sistèma de gestion deus ligams entre las diferentas reviradas d’un article.', # MODIF
	'texte_non_compresse' => '<i>non comprimit</i> (pr’amor que lo vòste servider non supòrta pas aquera foncionalitat)',
	'texte_nouvelle_version_spip_1' => 'Qu’avetz installada ua version navèra d’SPIP.',
	'texte_nouvelle_version_spip_2' => 'Aquesta version navèra que demanda ua actualizacion mei completa que de costuma. S’ètz webmèstre/webmèstra deu sit, volhatz esfaçar lo fichièr <tt>inc_connect.php3</tt> deu repertòri <tt>ecrire</tt> e tornar préner l’installacion entà actualizar los vòstes paramètres de connexion a la basa de dadas.<p> (NB: s’avetz desmembrat los vòstes paramètres de connexion, espiatz lo fichièr  <tt>inc_connect.php3</tt> abans de suprimí’u...)</p>', # MODIF
	'texte_operation_echec' => 'Tornatz a la pagina precedenta, causitz ua auta basa o creatz-ne ua navèra. Verificatz las informacions que lo vòste aubergader a hornidas.',
	'texte_plus_trois_car' => 'mei de 3 caractèrs',
	'texte_plusieurs_articles' => 'Mei d’un autor trobat entà "@cherche_auteur@":',
	'texte_port_annuaire' => '(La valor indicada com predefinida que convien en generau.)',
	'texte_proposer_publication' => 'Quora auratz acabat lo vòste article,<br /> que poiratz perpausar que sia publicat.',
	'texte_proxy' => 'Dens daubuns cas (intranet, arrets protegits...),
  qu’es pòt que calha utilizar un <i>proxy HTTP</i> tà aténher los sits sindicats.
  En aqueth cas, marcatz ça devath la soa adreiça, devath la forma
  <tt><html>http://proxy:8080</html></tt>. En generau,
 que deisharatz vueida aquera casa.',
	'texte_publication_articles_post_dates' => 'Quin SPIP deu comportà’s fàcia aus articles que la lor
  data de publicacion ei fixada a ua 
  escadença futura?',
	'texte_rappel_selection_champs' => '[N’oblidetz pas de seleccionar aqueth camp corrèctament.]',
	'texte_recalcul_page' => 'Se voletz
tornar calcular sonque ua pagina, passatz meilèu per l’espaci public e utilizatz lo  boton "tornar calcular".',
	'texte_recuperer_base' => 'Reparar la basa de dadas',
	'texte_reference_mais_redirige' => 'article referenciat dens lo vòste sit SPIP, mes redirigit de cap tà ua autra URL.',
	'texte_requetes_echouent' => '<b>Quora daubuas requèstas SQL s’i mauescaden
  sistematicament e shens rason aparenta, que’s pòt
  qu’aquò venga de la quita basa de dadas.  </b><p>
  SQL que tien la facultat de reparar las soas
  taulas quan un accident las
 a guastadas. Ací que podetz ensajar aquera reparacion; se 
  non s’i escad pas, servatz ua còpia de l’afichatge, que contien
 dilhèu indicis de çò qui non va pas...<p>
  Se lo problèma e persisteish, contactatz lo vòste
  aubergader.<p>', # MODIF
	'texte_selection_langue_principale' => 'Que podetz seleccionar ça devath la "lenga principau" deu sit. Aquera causida non vs’obliga pas -gran gai- d’escríver los vòstes articles dens la lenga seleccionada, mes que permet de determinar:
 <ul><li> lo format predefinit de las datas suu sit public;</li>
 <li> la natura deu motor tipografic que SPIP e deu utilizar tau rendut deus tèxts;</li>
 <li> la lenga utilizada dens los formularis deu sit public;</li>
 <li> la lenga presentada com predefinida dens l’espaci privat.</li></ul>',
	'texte_sous_titre' => 'Sostítol',
	'texte_statistiques_visites' => '(barras escuras:  dimenge / corba escura: evolucion de la mejana)',
	'texte_statut_attente_validation' => 'en espèra de validacion',
	'texte_statut_publies' => 'publicats en linha',
	'texte_statut_refuses' => 'arrefusats',
	'texte_suppression_fichiers' => 'Utilizatz aquera comanda tà suprimir tots los fichièrs qui’s tròban
dens l’esconeder SPIP. Aquò que permet per exemple de forçar un calcul nau de totas las paginas
s’avetz modificat de bèth pro lo grafisme o l’estructura deu sit.',
	'texte_sur_titre' => 'Subertítol',
	'texte_table_ok' => ': aquesta taula qu’ei condreta.',
	'texte_tentative_recuperation' => 'Ensai de reparacion',
	'texte_tenter_reparation' => 'Ensajar de reparar la basa de dadas',
	'texte_test_proxy' => 'Tà ensajar aqueth proxy, indicatz ací l’adreiça d’un sit web
    qui voleretz esprovar.',
	'texte_titre_02' => 'Títol:',
	'texte_titre_obligatoire' => '<b>Títol</b> [Obligatòri]',
	'texte_travail_article' => '@nom_auteur_modif@ qu’a trabalhat sus aqueth article @date_diff@ minutas a',
	'texte_travail_collaboratif' => 'Quora ei frequent que mei d’un redactor 
  e trabalhe suu medish article, lo sistèma
  que pòt afichar los articles recentament "aubèrts"
  entà evitar las modificacions simultanèas.
  Aquera opcion qu’ei desactivada de manèra predefinida
  entà evitar d’afichar messatges d’avertiment
  intempestius.', # MODIF
	'texte_vide' => 'vueid',
	'texte_vider_cache' => 'Vueidar l’esconeder',
	'titre_admin_tech' => 'Mantienença tecnica',
	'titre_cadre_afficher_article' => 'Afichar los articles',
	'titre_cadre_afficher_traductions' => 'Afichar l’estat de las arreviradas tà las lengas seguentas:',
	'titre_cadre_ajouter_auteur' => 'AJUSTAR UN AUTOR:',
	'titre_cadre_interieur_rubrique' => 'Laguens la rubrica',
	'titre_cadre_numero_auteur' => 'AUTOR NUMÈRO',
	'titre_cadre_signature_obligatoire' => '<b>Signatura</b> [Obligatòria]<br />',
	'titre_config_fonctions' => 'Configuracion deu sit',
	'titre_configuration' => 'Configuracion deu sit',
	'titre_connexion_ldap' => 'Opcions: <b>La vòsta connexion LDAP</b>',
	'titre_groupe_mots' => 'GROP DE MOTS:',
	'titre_langue_article' => 'LENGA DE L’ARTICLE', # MODIF
	'titre_langue_rubrique' => 'LENGA DE LA RUBRICA', # MODIF
	'titre_langue_trad_article' => 'LENGA E ARREVIRADAS DE L’ARTICLE',
	'titre_les_articles' => 'LOS ARTICLES',
	'titre_naviguer_dans_le_site' => 'Navigar peu lo sit...',
	'titre_nouvelle_rubrique' => 'Rubrica navèra',
	'titre_numero_rubrique' => 'RUBRICA NUMÈRO:',
	'titre_page_articles_edit' => 'Modificar: @titre@',
	'titre_page_articles_page' => 'Los articles',
	'titre_page_articles_tous' => 'Tot lo sit',
	'titre_page_calendrier' => 'Calendèr @nom_mois@ de @annee@',
	'titre_page_config_contenu' => 'Configuracion deu sit',
	'titre_page_delete_all' => 'supression totau e irreversibla',
	'titre_page_recherche' => 'Resultats de la cèrca @recherche@',
	'titre_page_statistiques_referers' => 'Estadisticas (ligams entrants)',
	'titre_page_upgrade' => 'Hicada a nivèu d’SPIP',
	'titre_publication_articles_post_dates' => 'Publicacion deus articles pòstdatats',
	'titre_reparation' => 'Reparacion',
	'titre_suivi_petition' => 'Seguit de las peticions',
	'trad_article_traduction' => 'Totas las versions d’aqueth article:',
	'trad_delier' => 'Non ligar plus aqueste article a las soas arreviradas ', # MODIF
	'trad_lier' => 'Aqueste article qu’ei ua arrevirada de l’article numèro:',
	'trad_new' => 'Escríver ua arrevirada navèra d’aqueste article', # MODIF
];
